0.7
---

* Add ``-s`` option to select data to display in the terminal
  https://github.com/European-XFEL/h5glance/pull/16
* Show data for attributes containing small arrays
  https://github.com/European-XFEL/h5glance/pull/15
* More accurate description of non-standard datatypes
  https://github.com/European-XFEL/h5glance/pull/17
* Better document installation and completions in the shell
  https://github.com/European-XFEL/h5glance/pull/18
* Added 'Why H5Glance' to the README
  https://github.com/European-XFEL/h5glance/pull/20

0.6
---

* Added support for h5pyd objects in the notebook interface:
  https://github.com/European-XFEL/h5glance/pull/11
* Improved expand/collapse icons in the notebook interface:
  https://github.com/European-XFEL/h5glance/pull/12
* Don't crash the terminal interface when attributes are unreadable:
  https://github.com/European-XFEL/h5glance/pull/13
